summaryrefslogtreecommitdiffstats
path: root/kate
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-11-06 11:29:10 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-11-07 10:49:54 +0900
commit96f327c14acd697b936e88289165e0edb57d7fb6 (patch)
treefdf24ccd79bca9a6085d35a670c7299cb2a27fe3 /kate
parentd48a4e1b0d41fa262f29142736d11ce22cffa657 (diff)
downloadtdeaddons-96f327c14acd697b936e88289165e0edb57d7fb6.tar.gz
tdeaddons-96f327c14acd697b936e88289165e0edb57d7fb6.zip
Replace Qt with TQt
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'kate')
-rw-r--r--kate/cppsymbolviewer/plugin_katesymbolviewer.cpp2
-rw-r--r--kate/insertcommand/plugin_kateinsertcommand.cpp2
-rw-r--r--kate/snippets/plugin_katesnippets.cpp4
-rw-r--r--kate/tabbarextension/plugin_katetabbarextension.cpp18
-rw-r--r--kate/tabbarextension/plugin_katetabbarextension.h12
5 files changed, 19 insertions, 19 deletions
diff --git a/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp b/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp
index 3de7fa2..a8175d2 100644
--- a/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp
+++ b/kate/cppsymbolviewer/plugin_katesymbolviewer.cpp
@@ -315,7 +315,7 @@ KatePluginSymbolViewerConfigPage::KatePluginSymbolViewerConfigPage(
TQGroupBox* gb = new TQGroupBox( i18n("Parser Options"),
this, "cppsymbolviewer_config_page_layout" );
- gb->setColumnLayout(1, Qt::Horizontal);
+ gb->setColumnLayout(1, TQt::Horizontal);
gb->setInsideSpacing(KDialogBase::spacingHint());
viewReturns = new TQCheckBox(i18n("Display functions parameters"), gb);
expandTree = new TQCheckBox(i18n("Automatically expand nodes in tree mode"), gb);
diff --git a/kate/insertcommand/plugin_kateinsertcommand.cpp b/kate/insertcommand/plugin_kateinsertcommand.cpp
index 37b72c3..cdbe0a2 100644
--- a/kate/insertcommand/plugin_kateinsertcommand.cpp
+++ b/kate/insertcommand/plugin_kateinsertcommand.cpp
@@ -385,7 +385,7 @@ InsertCommandConfigPage::InsertCommandConfigPage(TQObject* /*parent*/,
// dir history length
// initial dir choice
- rg_startin = new TQButtonGroup( 1, Qt::Horizontal, i18n("Start In"), this );
+ rg_startin = new TQButtonGroup( 1, TQt::Horizontal, i18n("Start In"), this );
rg_startin->setRadioButtonExclusive( true );
(void) new TQRadioButton( i18n("Application &working folder"), rg_startin);
(void) new TQRadioButton( i18n("&Document folder"), rg_startin);
diff --git a/kate/snippets/plugin_katesnippets.cpp b/kate/snippets/plugin_katesnippets.cpp
index d895989..856cfbc 100644
--- a/kate/snippets/plugin_katesnippets.cpp
+++ b/kate/snippets/plugin_katesnippets.cpp
@@ -171,8 +171,8 @@ void KatePluginSnippetsView::slot_lvSnippetsClicked (TQListViewItem * item) {
}
sText.replace( TQRegExp("<mark/>"), sSelection );
- sText.replace( TQRegExp("<date/>"), TQDate::currentDate().toString(Qt::LocalDate) );
- sText.replace( TQRegExp("<time/>"), TQTime::currentTime().toString(Qt::LocalDate) );
+ sText.replace( TQRegExp("<date/>"), TQDate::currentDate().toString(TQt::LocalDate) );
+ sText.replace( TQRegExp("<time/>"), TQTime::currentTime().toString(TQt::LocalDate) );
kv->insertText ( sText );
}
kv->setFocus();
diff --git a/kate/tabbarextension/plugin_katetabbarextension.cpp b/kate/tabbarextension/plugin_katetabbarextension.cpp
index 51d675d..e26524c 100644
--- a/kate/tabbarextension/plugin_katetabbarextension.cpp
+++ b/kate/tabbarextension/plugin_katetabbarextension.cpp
@@ -112,8 +112,8 @@ void KatePluginTabBarExtension::addView(Kate::MainWindow *win)
TDEToolBar* toolbar = dynamic_cast<TDEToolBar*>
(win->guiFactory()->container("tabbarExtensionToolBar", view));
if (toolbar) {
- connect(toolbar, TQT_SIGNAL(orientationChanged(Qt::Orientation)),
- view->tabbar, TQT_SLOT(slotMoved(Qt::Orientation)));
+ connect(toolbar, TQT_SIGNAL(orientationChanged(TQt::Orientation)),
+ view->tabbar, TQT_SLOT(slotMoved(TQt::Orientation)));
}
}
@@ -128,7 +128,7 @@ void KatePluginTabBarExtension::removeView(Kate::MainWindow *win)
if (m_views.count() == 1)
{
pConfig->writeEntry("horizontal orientation",
- view->tabbar->orientation()==Qt::Horizontal?true:false);
+ view->tabbar->orientation()==TQt::Horizontal?true:false);
pConfig->writeEntry("sort", view->tabbar->sortByName());
pConfig->writeEntry("closeOnMiddleClick", view->tabbar->closeOnMiddleClick());
pConfig->sync();
@@ -270,10 +270,10 @@ KateTabBarExtension::KateTabBarExtension(Kate::DocumentManager *pDocManager,
{
if (bHorizOrientation) {
top = new TQBoxLayout(this, TQBoxLayout::LeftToRight);
- m_orientation = Qt::Horizontal;
+ m_orientation = TQt::Horizontal;
} else {
top = new TQBoxLayout(this, TQBoxLayout::TopToBottom);
- m_orientation = Qt::Vertical;
+ m_orientation = TQt::Vertical;
}
// add all already existing documents to the tabbar
@@ -294,15 +294,15 @@ KateTabBarExtension::KateTabBarExtension(Kate::DocumentManager *pDocManager,
setCloseOnMiddleClick(bCloseOnMiddleClick);
}
-void KateTabBarExtension::slotMoved(Qt::Orientation o)
+void KateTabBarExtension::slotMoved(TQt::Orientation o)
{
// the tabbar moved (top, right, bottom, left or fluently)
switch (o) {
- case Qt::Vertical:
+ case TQt::Vertical:
top->setDirection(TQBoxLayout::TopToBottom);
break;
- case Qt::Horizontal:
+ case TQt::Horizontal:
top->setDirection(TQBoxLayout::LeftToRight);
break;
}
@@ -480,7 +480,7 @@ KateTabBarExtensionConfigPage::KateTabBarExtensionConfigPage(
TQVBoxLayout* top = new TQVBoxLayout(this, 0,
KDialogBase::spacingHint());
- TQGroupBox* gb = new TQGroupBox(1, Qt::Horizontal, i18n("Behavior options"),
+ TQGroupBox* gb = new TQGroupBox(1, TQt::Horizontal, i18n("Behavior options"),
this, "tab_bar_extension_config_page_layout" );
gb->setInsideSpacing(KDialogBase::spacingHint());
pSortAlpha = new TQCheckBox(i18n("Sort files alphabetically"), gb);
diff --git a/kate/tabbarextension/plugin_katetabbarextension.h b/kate/tabbarextension/plugin_katetabbarextension.h
index 710eb97..f991c42 100644
--- a/kate/tabbarextension/plugin_katetabbarextension.h
+++ b/kate/tabbarextension/plugin_katetabbarextension.h
@@ -179,8 +179,8 @@ class KateTabBarExtension : public TQWidget
* constructor
* @param pDocManager pointer to kate's document manager
* @param win pinter to the main window
- * @param bHorizOrientation true, if orientation is Qt::Horizontal
- * @param bSort true, if orientation is Qt::Horizontal
+ * @param bHorizOrientation true, if orientation is Horizontal
+ * @param bSort true, if orientation is Horizontal
* @param parent parent widget
* @param name name of widget
* @param f widget flags
@@ -196,7 +196,7 @@ class KateTabBarExtension : public TQWidget
/**
* @return the tabbar's orientation
*/
- Qt::Orientation orientation() const { return m_orientation; }
+ TQt::Orientation orientation() const { return m_orientation; }
/**
* @return true, when sorting is alphabetically
@@ -271,9 +271,9 @@ class KateTabBarExtension : public TQWidget
/**
* called whenever the toolbar's orientation changes
* @param o new orientation [Qt::Horizontal or Qt::Vertical]
*/
- void slotMoved(Qt::Orientation o);
+ void slotMoved(TQt::Orientation o);
/**
* called when we want to close the document associated with the tab
@@ -288,7 +288,7 @@ class KateTabBarExtension : public TQWidget
Kate::DocumentManager* m_docManager; ///< pointer to the document manager
// TQPtrList <KateTabBarButton> m_tabs; ///< list containing all tabs
MyPtrList m_tabs; ///< list containing all tabs
- Qt::Orientation m_orientation; ///< save tabbar's orientation
+ TQt::Orientation m_orientation; ///< save tabbar's orientation
bool m_sort; ///< how to sort
bool m_closeOnMiddleClick; ///< Enable/disable "close document on mouse middle click" feature
};
@@ -271,9 +271,9 @@ class KateTabBarExtension : public TQWidget
/**
* called whenever the toolbar's orientation changes
- * @param o new orientation [Qt::Horizontal or Qt::Vertical]
+ * @param o new orientation [TQt::Horizontal or TQt::Vertical]
*/